@@ -2,6 +2,6 @@
 # -*- coding: utf-8 -*-
 
 from .focalloss import FocalLoss
-from .circleloss import CircleLoss
+from .circleloss import CircleLoss  #, convert_label_to_similarity
 from .label_smoothing import LabelSmoothingCrossEntropy
 from .dice_loss import DiceLoss
